summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--kdoctools/CMakeLists.txt16
-rw-r--r--kdoctools/Makefile.am20
-rw-r--r--kdoctools/ghelp.protocol2
-rw-r--r--kdoctools/help.protocol2
-rw-r--r--kdoctools/kio_help.upd3
-rw-r--r--kdoctools/main.cpp6
-rw-r--r--kdoctools/main_ghelp.cpp6
-rw-r--r--kdoctools/meinproc.cpp2
-rw-r--r--kdoctools/move_tdeio_help_cache.sh (renamed from kdoctools/move_kio_help_cache.sh)2
-rw-r--r--kdoctools/tdeio_help.cpp (renamed from kdoctools/kio_help.cpp)6
-rw-r--r--kdoctools/tdeio_help.h (renamed from kdoctools/kio_help.h)0
-rw-r--r--kdoctools/tdeio_help.upd3
-rw-r--r--kdoctools/xslt.cpp4
-rw-r--r--tdeioslave/file/CMakeLists.txt4
-rw-r--r--tdeioslave/file/Makefile.am8
-rw-r--r--tdeioslave/file/file.cc6
-rw-r--r--tdeioslave/file/file.protocol2
-rw-r--r--tdeioslave/ftp/CMakeLists.txt4
-rw-r--r--tdeioslave/ftp/Makefile.am8
-rw-r--r--tdeioslave/ftp/configure.in.in2
-rw-r--r--tdeioslave/ftp/ftp.cc18
-rw-r--r--tdeioslave/ftp/ftp.h8
-rw-r--r--tdeioslave/ftp/ftp.protocol2
-rw-r--r--tdeioslave/http/CMakeLists.txt8
-rw-r--r--tdeioslave/http/Makefile.am18
-rw-r--r--tdeioslave/http/README.http_cache_cleaner4
-rw-r--r--tdeioslave/http/README.webdav2
-rw-r--r--tdeioslave/http/TODO4
-rw-r--r--tdeioslave/http/http.cc12
-rw-r--r--tdeioslave/http/http.protocol2
-rw-r--r--tdeioslave/http/http_cache_cleaner.cpp2
-rw-r--r--tdeioslave/http/http_cache_cleaner.desktop2
-rw-r--r--tdeioslave/http/https.protocol2
-rw-r--r--tdeioslave/http/kcookiejar/kcookiejar.cpp2
-rw-r--r--tdeioslave/http/webdav.protocol2
-rw-r--r--tdeioslave/http/webdavs.protocol2
-rw-r--r--tdeioslave/iso/CMakeLists.txt8
-rw-r--r--tdeioslave/iso/Makefile.am12
-rw-r--r--tdeioslave/iso/iso.cpp44
-rw-r--r--tdeioslave/iso/iso.h6
-rw-r--r--tdeioslave/iso/iso.protocol2
-rw-r--r--tdeioslave/iso/kiso.cpp2
-rw-r--r--tdeioslave/iso/tdeio_iso.desktop (renamed from tdeioslave/iso/kio_iso.desktop)0
-rw-r--r--tdeioslave/iso/tdeio_isorc (renamed from tdeioslave/iso/kio_isorc)0
-rw-r--r--tdeioslave/metainfo/CMakeLists.txt4
-rw-r--r--tdeioslave/metainfo/Makefile.am8
-rw-r--r--tdeioslave/metainfo/metainfo.cpp4
-rw-r--r--tdeioslave/metainfo/metainfo.protocol2
48 files changed, 144 insertions, 144 deletions
diff --git a/kdoctools/CMakeLists.txt b/kdoctools/CMakeLists.txt
index 09b04a8ea..8657e277e 100644
--- a/kdoctools/CMakeLists.txt
+++ b/kdoctools/CMakeLists.txt
@@ -33,8 +33,8 @@ link_directories(
##### other data ################################
install( PROGRAMS ${CMAKE_CURRENT_BINARY_DIR}/checkXML DESTINATION ${BIN_INSTALL_DIR} )
-install( PROGRAMS move_kio_help_cache.sh DESTINATION ${KCONF_UPDATE_INSTALL_DIR} )
-install( FILES kio_help.upd DESTINATION ${KCONF_UPDATE_INSTALL_DIR} )
+install( PROGRAMS move_tdeio_help_cache.sh DESTINATION ${KCONF_UPDATE_INSTALL_DIR} )
+install( FILES tdeio_help.upd DESTINATION ${KCONF_UPDATE_INSTALL_DIR} )
install( FILES help.protocol ghelp.protocol DESTINATION ${SERVICES_INSTALL_DIR} )
# FIXME why automake version is so complicated?
@@ -58,12 +58,12 @@ tde_add_library( kbzipfilter_dummy STATIC_PIC
)
-#### kio_help ###################################
+#### tdeio_help ###################################
-set( target kio_help )
+set( target tdeio_help )
set( ${target}_SRCS
- kio_help.cpp main.cpp xslt.cpp
+ tdeio_help.cpp main.cpp xslt.cpp
)
tde_add_kpart( ${target} SHARED
@@ -73,12 +73,12 @@ tde_add_kpart( ${target} SHARED
)
-#### kio_ghelp ###################################
+#### tdeio_ghelp ###################################
-set( target kio_ghelp )
+set( target tdeio_ghelp )
set( ${target}_SRCS
- kio_help.cpp main_ghelp.cpp xslt.cpp
+ tdeio_help.cpp main_ghelp.cpp xslt.cpp
)
tde_add_kpart( ${target} SHARED
diff --git a/kdoctools/Makefile.am b/kdoctools/Makefile.am
index 05c3487cd..c009fd19d 100644
--- a/kdoctools/Makefile.am
+++ b/kdoctools/Makefile.am
@@ -8,17 +8,17 @@ libkbzipfilter_dummy_la_SOURCES = kbzip2filter.cpp
####### Files
-kde_module_LTLIBRARIES = kio_help.la kio_ghelp.la
+kde_module_LTLIBRARIES = tdeio_help.la tdeio_ghelp.la
-kio_help_la_SOURCES = kio_help.cpp main.cpp xslt.cpp
-kio_help_la_LIBADD = $(LIBXSLT_LIBS) $(LIBXML_LIBS) libkbzipfilter_dummy.la $(LIB_KIO) $(LIBBZ2) $(LIB_QT) $(LIB_TDECORE)
-kio_help_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN)
+tdeio_help_la_SOURCES = tdeio_help.cpp main.cpp xslt.cpp
+tdeio_help_la_LIBADD = $(LIBXSLT_LIBS) $(LIBXML_LIBS) libkbzipfilter_dummy.la $(LIB_KIO) $(LIBBZ2) $(LIB_QT) $(LIB_TDECORE)
+tdeio_help_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN)
-kio_ghelp_la_SOURCES = kio_help.cpp main_ghelp.cpp xslt.cpp
-kio_ghelp_la_LIBADD = $(LIBXSLT_LIBS) $(LIBXML_LIBS) libkbzipfilter_dummy.la $(LIB_KIO) $(LIBBZ2) $(LIB_QT) $(LIB_TDECORE)
-kio_ghelp_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN)
+tdeio_ghelp_la_SOURCES = tdeio_help.cpp main_ghelp.cpp xslt.cpp
+tdeio_ghelp_la_LIBADD = $(LIBXSLT_LIBS) $(LIBXML_LIBS) libkbzipfilter_dummy.la $(LIB_KIO) $(LIBBZ2) $(LIB_QT) $(LIB_TDECORE)
+tdeio_ghelp_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN)
-noinst_HEADERS = kio_help.h
+noinst_HEADERS = tdeio_help.h
kdelnk_DATA = help.protocol ghelp.protocol
kdelnkdir = $(kde_servicesdir)
@@ -36,8 +36,8 @@ bin_SCRIPTS = checkXML
METASOURCES = AUTO
-update_DATA = kio_help.upd
-update_SCRIPTS = move_kio_help_cache.sh
+update_DATA = tdeio_help.upd
+update_SCRIPTS = move_tdeio_help_cache.sh
updatedir = $(kde_datadir)/tdeconf_update
messages:
diff --git a/kdoctools/ghelp.protocol b/kdoctools/ghelp.protocol
index ec5e50a34..f8dca77c2 100644
--- a/kdoctools/ghelp.protocol
+++ b/kdoctools/ghelp.protocol
@@ -1,5 +1,5 @@
[Protocol]
-exec=kio_ghelp
+exec=tdeio_ghelp
protocol=ghelp
input=none
output=filesystem
diff --git a/kdoctools/help.protocol b/kdoctools/help.protocol
index b4ee178e6..dc7a25b16 100644
--- a/kdoctools/help.protocol
+++ b/kdoctools/help.protocol
@@ -1,5 +1,5 @@
[Protocol]
-exec=kio_help
+exec=tdeio_help
protocol=help
input=none
output=filesystem
diff --git a/kdoctools/kio_help.upd b/kdoctools/kio_help.upd
deleted file mode 100644
index cca96f64b..000000000
--- a/kdoctools/kio_help.upd
+++ /dev/null
@@ -1,3 +0,0 @@
-# Move kio_help cache from $TDEHOME/share/apps/tdeio_help/cache to $TDEHOME/cache-$HOST/tdeio_help
-Id=trinity_2
-Script=move_kio_help_cache.sh,sh
diff --git a/kdoctools/main.cpp b/kdoctools/main.cpp
index 7ba294bfb..57a44156c 100644
--- a/kdoctools/main.cpp
+++ b/kdoctools/main.cpp
@@ -16,7 +16,7 @@
#include <kinstance.h>
#include <kdebug.h>
#include <stdlib.h>
-#include "kio_help.h"
+#include "tdeio_help.h"
#include <xslt.h>
extern int xmlLoadExtDtdDefaultValue;
@@ -25,7 +25,7 @@ extern "C"
{
KDE_EXPORT int kdemain( int argc, char **argv )
{
- TDEInstance instance( "kio_help" );
+ TDEInstance instance( "tdeio_help" );
fillInstance(instance);
(void)instance.config(); // we need this one to make sure system globals are read
@@ -33,7 +33,7 @@ extern "C"
if (argc != 4)
{
- fprintf(stderr, "Usage: kio_help protocol domain-socket1 domain-socket2\n");
+ fprintf(stderr, "Usage: tdeio_help protocol domain-socket1 domain-socket2\n");
exit(-1);
}
diff --git a/kdoctools/main_ghelp.cpp b/kdoctools/main_ghelp.cpp
index bbdb5d7c0..94bcc60dd 100644
--- a/kdoctools/main_ghelp.cpp
+++ b/kdoctools/main_ghelp.cpp
@@ -16,7 +16,7 @@
#include <kinstance.h>
#include <kdebug.h>
#include <stdlib.h>
-#include "kio_help.h"
+#include "tdeio_help.h"
#include <xslt.h>
extern int xmlLoadExtDtdDefaultValue;
@@ -25,7 +25,7 @@ extern "C"
{
KDE_EXPORT int kdemain( int argc, char **argv )
{
- TDEInstance instance( "kio_ghelp" );
+ TDEInstance instance( "tdeio_ghelp" );
fillInstance(instance);
(void)instance.config(); // we need this one to make sure system globals are read
@@ -33,7 +33,7 @@ extern "C"
if (argc != 4)
{
- fprintf(stderr, "Usage: kio_ghelp protocol domain-socket1 domain-socket2\n");
+ fprintf(stderr, "Usage: tdeio_ghelp protocol domain-socket1 domain-socket2\n");
exit(-1);
}
diff --git a/kdoctools/meinproc.cpp b/kdoctools/meinproc.cpp
index 1c47ec43f..034218546 100644
--- a/kdoctools/meinproc.cpp
+++ b/kdoctools/meinproc.cpp
@@ -98,7 +98,7 @@ int main(int argc, char **argv) {
TDECmdLineArgs::init(argc, argv, &aboutData);
TDECmdLineArgs::addCmdLineOptions( options );
- KLocale::setMainCatalogue("kio_help");
+ KLocale::setMainCatalogue("tdeio_help");
TDEInstance ins("meinproc");
TDEGlobal::locale();
diff --git a/kdoctools/move_kio_help_cache.sh b/kdoctools/move_tdeio_help_cache.sh
index f1342c5b4..33096e885 100644
--- a/kdoctools/move_kio_help_cache.sh
+++ b/kdoctools/move_tdeio_help_cache.sh
@@ -1,6 +1,6 @@
#!/bin/sh
bas=`tde-config --localprefix`share/apps/tdeio_help
-mv "$bas/cache" "`tde-config --path cache`kio_help"
+mv "$bas/cache" "`tde-config --path cache`tdeio_help"
rmdir "$bas"
exit 0
diff --git a/kdoctools/kio_help.h b/kdoctools/tdeio_help.h
index df002df15..df002df15 100644
--- a/kdoctools/kio_help.h
+++ b/kdoctools/tdeio_help.h
diff --git a/kdoctools/tdeio_help.upd b/kdoctools/tdeio_help.upd
new file mode 100644
index 000000000..4be705f6e
--- /dev/null
+++ b/kdoctools/tdeio_help.upd
@@ -0,0 +1,3 @@
+# Move tdeio_help cache from $TDEHOME/share/apps/tdeio_help/cache to $TDEHOME/cache-$HOST/tdeio_help
+Id=trinity_2
+Script=move_tdeio_help_cache.sh,sh
diff --git a/kdoctools/xslt.cpp b/kdoctools/xslt.cpp
index 6653c7cd5..d143e0a06 100644
--- a/kdoctools/xslt.cpp
+++ b/kdoctools/xslt.cpp
@@ -11,7 +11,7 @@
#include <tqregexp.h>
#include <xslt.h>
#include <kinstance.h>
-#include "kio_help.h"
+#include "tdeio_help.h"
#include <klocale.h>
#include <assert.h>
#include <kfilterbase.h>
@@ -287,7 +287,7 @@ TQString lookForCache( const TQString &filename )
return output;
if ( readCache( filename,
locateLocal( "cache",
- "kio_help" + cache +
+ "tdeio_help" + cache +
"cache.bz2" ), output ) )
return output;
diff --git a/tdeioslave/file/CMakeLists.txt b/tdeioslave/file/CMakeLists.txt
index 0392de535..287e1ebe2 100644
--- a/tdeioslave/file/CMakeLists.txt
+++ b/tdeioslave/file/CMakeLists.txt
@@ -39,9 +39,9 @@ install( FILES file.h DESTINATION ${INCLUDE_INSTALL_DIR}/tdeio )
install( FILES file.protocol DESTINATION ${SERVICES_INSTALL_DIR} )
-##### kio_file ##################################
+##### tdeio_file ##################################
-set( target kio_file )
+set( target tdeio_file )
set( ${target}_SRCS
file.cc
diff --git a/tdeioslave/file/Makefile.am b/tdeioslave/file/Makefile.am
index 518b79f46..0e34dda74 100644
--- a/tdeioslave/file/Makefile.am
+++ b/tdeioslave/file/Makefile.am
@@ -6,11 +6,11 @@ INCLUDES = $(all_includes)
####### Files
-kde_module_LTLIBRARIES = kio_file.la
+kde_module_LTLIBRARIES = tdeio_file.la
-kio_file_la_SOURCES = file.cc
-kio_file_la_LIBADD = $(LIB_KIO) $(LIB_QT) $(LIB_TDECORE) $(ACL_LIBS)
-kio_file_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN) $(top_builddir)/dcop/libDCOP.la
+tdeio_file_la_SOURCES = file.cc
+tdeio_file_la_LIBADD = $(LIB_KIO) $(LIB_QT) $(LIB_TDECORE) $(ACL_LIBS)
+tdeio_file_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN) $(top_builddir)/dcop/libDCOP.la
noinst_HEADERS = file.h
fileinclude_HEADERS = file.h
diff --git a/tdeioslave/file/file.protocol b/tdeioslave/file/file.protocol
index be7c5d587..270a2f208 100644
--- a/tdeioslave/file/file.protocol
+++ b/tdeioslave/file/file.protocol
@@ -1,5 +1,5 @@
[Protocol]
-exec=kio_file
+exec=tdeio_file
protocol=file
input=none
output=filesystem
diff --git a/tdeioslave/ftp/CMakeLists.txt b/tdeioslave/ftp/CMakeLists.txt
index 9f9125fc3..5cc0694b8 100644
--- a/tdeioslave/ftp/CMakeLists.txt
+++ b/tdeioslave/ftp/CMakeLists.txt
@@ -29,9 +29,9 @@ link_directories(
install( FILES ftp.protocol DESTINATION ${SERVICES_INSTALL_DIR} )
-##### kio_ftp ###################################
+##### tdeio_ftp ###################################
-set( target kio_ftp )
+set( target tdeio_ftp )
set( ${target}_SRCS
ftp.cc
diff --git a/tdeioslave/ftp/Makefile.am b/tdeioslave/ftp/Makefile.am
index c062d6430..93ee77a5a 100644
--- a/tdeioslave/ftp/Makefile.am
+++ b/tdeioslave/ftp/Makefile.am
@@ -2,11 +2,11 @@ INCLUDES= $(all_includes)
####### Files
-kde_module_LTLIBRARIES = kio_ftp.la
+kde_module_LTLIBRARIES = tdeio_ftp.la
-kio_ftp_la_SOURCES = ftp.cc
-kio_ftp_la_LIBADD = $(LIB_KIO) $(LIB_QT) $(LIB_TDECORE)
-kio_ftp_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN)
+tdeio_ftp_la_SOURCES = ftp.cc
+tdeio_ftp_la_LIBADD = $(LIB_KIO) $(LIB_QT) $(LIB_TDECORE)
+tdeio_ftp_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN)
noinst_HEADERS = ftp.h
diff --git a/tdeioslave/ftp/configure.in.in b/tdeioslave/ftp/configure.in.in
index 0c94a9b9b..b072643ca 100644
--- a/tdeioslave/ftp/configure.in.in
+++ b/tdeioslave/ftp/configure.in.in
@@ -1,4 +1,4 @@
-dnl For kio_ftp
+dnl For tdeio_ftp
AC_LANG_SAVE
AC_LANG_CPLUSPLUS
AC_CHECK_FUNCS( setfsent )
diff --git a/tdeioslave/ftp/ftp.h b/tdeioslave/ftp/ftp.h
index 4b2a1891d..c95b25410 100644
--- a/tdeioslave/ftp/ftp.h
+++ b/tdeioslave/ftp/ftp.h
@@ -53,7 +53,7 @@ struct FtpEntry
// FtpTextReader A helper class to read text lines from a socket
//===============================================================================
-#ifdef KIO_FTP_PRIVATE_INCLUDE
+#ifdef TDEIO_FTP_PRIVATE_INCLUDE
class FtpSocket;
class FtpTextReader
@@ -131,12 +131,12 @@ private:
*/
int m_iTextBuff;
};
-#endif // KIO_FTP_PRIVATE_INCLUDE
+#endif // TDEIO_FTP_PRIVATE_INCLUDE
//===============================================================================
// FtpSocket Helper Class for Data or Control Connections
//===============================================================================
-#ifdef KIO_FTP_PRIVATE_INCLUDE
+#ifdef TDEIO_FTP_PRIVATE_INCLUDE
class FtpSocket : public FtpTextReader, public KExtendedSocket
{
private:
@@ -228,7 +228,7 @@ private:
};
#else
class FtpSocket;
-#endif // KIO_FTP_PRIVATE_INCLUDE
+#endif // TDEIO_FTP_PRIVATE_INCLUDE
//===============================================================================
// Ftp
diff --git a/tdeioslave/ftp/ftp.protocol b/tdeioslave/ftp/ftp.protocol
index dfed878a8..363b27c7c 100644
--- a/tdeioslave/ftp/ftp.protocol
+++ b/tdeioslave/ftp/ftp.protocol
@@ -1,5 +1,5 @@
[Protocol]
-exec=kio_ftp
+exec=tdeio_ftp
protocol=ftp
input=none
output=filesystem
diff --git a/tdeioslave/http/CMakeLists.txt b/tdeioslave/http/CMakeLists.txt
index 64abe1adb..aff6d0a4e 100644
--- a/tdeioslave/http/CMakeLists.txt
+++ b/tdeioslave/http/CMakeLists.txt
@@ -38,9 +38,9 @@ install( FILES
DESTINATION ${SERVICES_INSTALL_DIR} )
-##### kio_http_cache_cleaner ####################
+##### tdeio_http_cache_cleaner ####################
-set( target kio_http_cache_cleaner )
+set( target tdeio_http_cache_cleaner )
set( ${target}_SRCS
http_cache_cleaner.cpp
@@ -52,11 +52,11 @@ tde_add_tdeinit_executable( ${target} AUTOMOC
)
-##### kio_http ##################################
+##### tdeio_http ##################################
# FIXME GSSAPI support is not handled yet
-set( target kio_http )
+set( target tdeio_http )
set( ${target}_SRCS
http.cc
diff --git a/tdeioslave/http/Makefile.am b/tdeioslave/http/Makefile.am
index 184381b0f..71b6d0c60 100644
--- a/tdeioslave/http/Makefile.am
+++ b/tdeioslave/http/Makefile.am
@@ -10,17 +10,17 @@ AM_LDFLAGS = $(all_libraries) $(GSSAPI_RPATH)
bin_PROGRAMS=
lib_LTLIBRARIES=
-tdeinit_LTLIBRARIES = kio_http_cache_cleaner.la
-kde_module_LTLIBRARIES = kio_http.la
+tdeinit_LTLIBRARIES = tdeio_http_cache_cleaner.la
+kde_module_LTLIBRARIES = tdeio_http.la
-kio_http_la_SOURCES = http.cc
-kio_http_la_METASOURCES = AUTO
-kio_http_la_LIBADD = $(LIB_KIO) $(top_builddir)/tdeio/httpfilter/libhttpfilter.la $(LIB_QT) $(LIB_TDECORE) $(LIBZ) $(top_builddir)/dcop/libDCOP.la $(top_builddir)/tdeio/misc/tdentlm/libtdentlm.la
-kio_http_la_LDFLAGS = $(all_libraries) $(GSSAPI_RPATH) -module $(KDE_PLUGIN) $(GSSAPI_LIBS)
+tdeio_http_la_SOURCES = http.cc
+tdeio_http_la_METASOURCES = AUTO
+tdeio_http_la_LIBADD = $(LIB_KIO) $(top_builddir)/tdeio/httpfilter/libhttpfilter.la $(LIB_QT) $(LIB_TDECORE) $(LIBZ) $(top_builddir)/dcop/libDCOP.la $(top_builddir)/tdeio/misc/tdentlm/libtdentlm.la
+tdeio_http_la_LDFLAGS = $(all_libraries) $(GSSAPI_RPATH) -module $(KDE_PLUGIN) $(GSSAPI_LIBS)
-kio_http_cache_cleaner_la_SOURCES = http_cache_cleaner.cpp
-kio_http_cache_cleaner_la_LIBADD = $(LIB_KIO) $(LIB_QT) $(LIB_TDECORE) $(top_builddir)/dcop/libDCOP.la
-kio_http_cache_cleaner_la_LDFLAGS = -module -avoid-version
+tdeio_http_cache_cleaner_la_SOURCES = http_cache_cleaner.cpp
+tdeio_http_cache_cleaner_la_LIBADD = $(LIB_KIO) $(LIB_QT) $(LIB_TDECORE) $(top_builddir)/dcop/libDCOP.la
+tdeio_http_cache_cleaner_la_LDFLAGS = -module -avoid-version
noinst_HEADERS = http.h
diff --git a/tdeioslave/http/README.http_cache_cleaner b/tdeioslave/http/README.http_cache_cleaner
index 7714bfba6..839394aa4 100644
--- a/tdeioslave/http/README.http_cache_cleaner
+++ b/tdeioslave/http/README.http_cache_cleaner
@@ -10,11 +10,11 @@ TODO:
30 minutes / delte entries which end in .new and are
older than 30 minutes.
-* Let kio_http fill in expire dates other than 0.
+* Let tdeio_http fill in expire dates other than 0.
DONE:
-* Start khttpcache from kio_http if the file "cleaned"
+* Start khttpcache from tdeio_http if the file "cleaned"
is older than 30(?) minutes.
* Accept command line parameteres
diff --git a/tdeioslave/http/README.webdav b/tdeioslave/http/README.webdav
index c7ee900bb..d7f6cca26 100644
--- a/tdeioslave/http/README.webdav
+++ b/tdeioslave/http/README.webdav
@@ -15,7 +15,7 @@ Applications supporting extended webdav features
Much of the info here is elaborated by rfc #2518; the rest can be understood by reading
davPropStat() in http.cc, specifically the setMetaData() calls.
-Extended information is transferred via kio's metadata system...
+Extended information is transferred via tdeio's metadata system...
=== MISCELLANEOUS ===
Display Names (names suitable for presentation to the user) are passed as the metadata
diff --git a/tdeioslave/http/TODO b/tdeioslave/http/TODO
index 9dbf60a3e..adf81a978 100644
--- a/tdeioslave/http/TODO
+++ b/tdeioslave/http/TODO
@@ -1,5 +1,5 @@
The following is a list of items that are currently missing or partially implemented
-in kio_http:
+in tdeio_http:
- HTTP/1.1 Persistant Connections:
The header often specifies the timeout value used for connections.
@@ -19,7 +19,7 @@ features such as locking.
- Rating(s) support. http://www.w3.org/PICS:
This might involve an external program to parse the labels, and something to
configure access accordingly. There is only some basic things that need to be
-added to kio_http to support this. The majority of the work has to be done at the
+added to tdeio_http to support this. The majority of the work has to be done at the
application level. A tdehtml plugin in tdeaddons to do this might be a nice idea.
- P3P support:
diff --git a/tdeioslave/http/http.protocol b/tdeioslave/http/http.protocol
index 60f85c451..d5ad11f28 100644
--- a/tdeioslave/http/http.protocol
+++ b/tdeioslave/http/http.protocol
@@ -1,5 +1,5 @@
[Protocol]
-exec=kio_http
+exec=tdeio_http
protocol=http
input=none
output=filesystem
diff --git a/tdeioslave/http/http_cache_cleaner.cpp b/tdeioslave/http/http_cache_cleaner.cpp
index 554d221d5..b4d235c1c 100644
--- a/tdeioslave/http/http_cache_cleaner.cpp
+++ b/tdeioslave/http/http_cache_cleaner.cpp
@@ -48,7 +48,7 @@ time_t currentDate;
int m_maxCacheAge;
int m_maxCacheSize;
-static const char appName[] = "kio_http_cache_cleaner";
+static const char appName[] = "tdeio_http_cache_cleaner";
static const char description[] = I18N_NOOP("TDE HTTP cache maintenance tool");
diff --git a/tdeioslave/http/http_cache_cleaner.desktop b/tdeioslave/http/http_cache_cleaner.desktop
index 33cebb731..63410bdd5 100644
--- a/tdeioslave/http/http_cache_cleaner.desktop
+++ b/tdeioslave/http/http_cache_cleaner.desktop
@@ -82,7 +82,7 @@ Name[zh_CN]=HTTP 缓存清除程序
Name[zh_HK]=HTTP 快取清除程式
Name[zh_TW]=HTTP 快取清除程式
Name[zu]=Umhlanzi we-Cache ye-HTTP
-Exec=kio_http_cache_cleaner
+Exec=tdeio_http_cache_cleaner
Comment=Cleans up old entries from the HTTP cache
Comment[af]=Skoonmaak begin ou inskrywings van die Http kas
Comment[ar]=يزيل المداخل القديمة من كاش HTTP
diff --git a/tdeioslave/http/https.protocol b/tdeioslave/http/https.protocol
index 5d456599c..75ea1ad0f 100644
--- a/tdeioslave/http/https.protocol
+++ b/tdeioslave/http/https.protocol
@@ -1,5 +1,5 @@
[Protocol]
-exec=kio_http
+exec=tdeio_http
protocol=https
input=none
output=filesystem
diff --git a/tdeioslave/http/kcookiejar/kcookiejar.cpp b/tdeioslave/http/kcookiejar/kcookiejar.cpp
index 5cb8d9053..731dbd996 100644
--- a/tdeioslave/http/kcookiejar/kcookiejar.cpp
+++ b/tdeioslave/http/kcookiejar/kcookiejar.cpp
@@ -85,7 +85,7 @@
#define IP_ADDRESS_EXPRESSION "(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)"
// Note with respect to TQString::fromLatin1( )
-// Cookies are stored as 8 bit data and passed to kio_http as
+// Cookies are stored as 8 bit data and passed to tdeio_http as
// latin1 regardless of their actual encoding.
// L1 is used to indicate latin1 constants
diff --git a/tdeioslave/http/webdav.protocol b/tdeioslave/http/webdav.protocol
index 3fd6287f9..0c696e5e6 100644
--- a/tdeioslave/http/webdav.protocol
+++ b/tdeioslave/http/webdav.protocol
@@ -1,5 +1,5 @@
[Protocol]
-exec=kio_http
+exec=tdeio_http
protocol=webdav
input=none
output=filesystem
diff --git a/tdeioslave/http/webdavs.protocol b/tdeioslave/http/webdavs.protocol
index 12d97499a..eb88675b1 100644
--- a/tdeioslave/http/webdavs.protocol
+++ b/tdeioslave/http/webdavs.protocol
@@ -1,5 +1,5 @@
[Protocol]
-exec=kio_http
+exec=tdeio_http
protocol=webdavs
input=none
output=filesystem
diff --git a/tdeioslave/iso/CMakeLists.txt b/tdeioslave/iso/CMakeLists.txt
index df3bfeee1..89b5f0f38 100644
--- a/tdeioslave/iso/CMakeLists.txt
+++ b/tdeioslave/iso/CMakeLists.txt
@@ -31,13 +31,13 @@ link_directories(
install( FILES iso.protocol DESTINATION ${SERVICES_INSTALL_DIR} )
install( FILES isoservice.desktop DESTINATION ${DATA_INSTALL_DIR}/konqueror/servicemenus )
-install( FILES kio_isorc DESTINATION ${CONFIG_INSTALL_DIR} )
-install( FILES kio_iso.desktop DESTINATION ${APPS_INSTALL_DIR} )
+install( FILES tdeio_isorc DESTINATION ${CONFIG_INSTALL_DIR} )
+install( FILES tdeio_iso.desktop DESTINATION ${APPS_INSTALL_DIR} )
-##### kio_iso ###################################
+##### tdeio_iso ###################################
-set( target kio_iso )
+set( target tdeio_iso )
set( ${target}_SRCS
kisodirectory.cpp kisofile.cpp qfilehack.cpp
diff --git a/tdeioslave/iso/Makefile.am b/tdeioslave/iso/Makefile.am
index bc1c7b3ea..e7eec33f6 100644
--- a/tdeioslave/iso/Makefile.am
+++ b/tdeioslave/iso/Makefile.am
@@ -1,4 +1,4 @@
-kde_module_LTLIBRARIES = kio_iso.la
+kde_module_LTLIBRARIES = tdeio_iso.la
INCLUDES = $(all_includes)
@@ -6,18 +6,18 @@ INCLUDES = $(all_includes)
#LDFLAGS =
-kio_iso_la_METASOURCES=AUTO
+tdeio_iso_la_METASOURCES=AUTO
-kio_iso_la_SOURCES = kisodirectory.cpp kisofile.cpp qfilehack.cpp kiso.cpp iso.cpp
-kio_iso_la_LIBADD = libisofs/libisofs.la $(LIB_QT) $(LIB_TDECORE) $(LIB_KIO)
+tdeio_iso_la_SOURCES = kisodirectory.cpp kisofile.cpp qfilehack.cpp kiso.cpp iso.cpp
+tdeio_iso_la_LIBADD = libisofs/libisofs.la $(LIB_QT) $(LIB_TDECORE) $(LIB_KIO)
-kio_iso_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN)
+tdeio_iso_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN)
SUBDIRS = libisofs
noinst_HEADERS = iso.h kiso.h qfilehack.h kisofile.h kisodirectory.h
-EXTRA_DIST = iso.protocol isoservice.desktop kio_iso.desktop
+EXTRA_DIST = iso.protocol isoservice.desktop tdeio_iso.desktop
install-data-local:
$(mkinstalldirs) $(DESTDIR)$(kde_servicesdir)/
diff --git a/tdeioslave/iso/iso.cpp b/tdeioslave/iso/iso.cpp
index 59f5f781e..8696b0c67 100644
--- a/tdeioslave/iso/iso.cpp
+++ b/tdeioslave/iso/iso.cpp
@@ -60,17 +60,17 @@ extern "C" { KDE_EXPORT int kdemain(int argc, char **argv); }
int kdemain( int argc, char **argv )
{
- TDEInstance instance( "kio_iso" );
+ TDEInstance instance( "tdeio_iso" );
kdDebug() << "Starting " << getpid() << endl;
if (argc != 4)
{
- fprintf(stderr, "Usage: kio_iso protocol domain-socket1 domain-socket2\n");
+ fprintf(stderr, "Usage: tdeio_iso protocol domain-socket1 domain-socket2\n");
exit(-1);
}
- kio_isoProtocol slave(argv[2], argv[3]);
+ tdeio_isoProtocol slave(argv[2], argv[3]);
slave.dispatchLoop();
kdDebug() << "Done" << endl;
@@ -78,20 +78,20 @@ int kdemain( int argc, char **argv )
}
-kio_isoProtocol::kio_isoProtocol( const TQCString &pool, const TQCString &app ) : SlaveBase( "iso", pool, app )
+tdeio_isoProtocol::tdeio_isoProtocol( const TQCString &pool, const TQCString &app ) : SlaveBase( "iso", pool, app )
{
- kdDebug() << "kio_isoProtocol::kio_isoProtocol" << endl;
+ kdDebug() << "tdeio_isoProtocol::tdeio_isoProtocol" << endl;
m_isoFile = 0L;
}
-kio_isoProtocol::~kio_isoProtocol()
+tdeio_isoProtocol::~tdeio_isoProtocol()
{
delete m_isoFile;
}
-bool kio_isoProtocol::checkNewFile( TQString fullPath, TQString & path, int startsec )
+bool tdeio_isoProtocol::checkNewFile( TQString fullPath, TQString & path, int startsec )
{
- kdDebug() << "kio_isoProtocol::checkNewFile " << fullPath << " startsec: " <<
+ kdDebug() << "tdeio_isoProtocol::checkNewFile " << fullPath << " startsec: " <<
startsec << endl;
// Are we already looking at that file ?
@@ -105,7 +105,7 @@ bool kio_isoProtocol::checkNewFile( TQString fullPath, TQString & path, int star
if ( m_mtime == statbuf.st_mtime )
{
path = fullPath.mid( m_isoFile->fileName().length() );
- kdDebug() << "kio_isoProtocol::checkNewFile returning " << path << endl;
+ kdDebug() << "tdeio_isoProtocol::checkNewFile returning " << path << endl;
return true;
}
}
@@ -157,7 +157,7 @@ bool kio_isoProtocol::checkNewFile( TQString fullPath, TQString & path, int star
}
if ( isoFile.isEmpty() )
{
- kdDebug() << "kio_isoProtocol::checkNewFile: not found" << endl;
+ kdDebug() << "tdeio_isoProtocol::checkNewFile: not found" << endl;
return false;
}
@@ -177,7 +177,7 @@ bool kio_isoProtocol::checkNewFile( TQString fullPath, TQString & path, int star
}
-void kio_isoProtocol::createUDSEntry( const KArchiveEntry * isoEntry, UDSEntry & entry )
+void tdeio_isoProtocol::createUDSEntry( const KArchiveEntry * isoEntry, UDSEntry & entry )
{
UDSAtom atom;
@@ -230,9 +230,9 @@ void kio_isoProtocol::createUDSEntry( const KArchiveEntry * isoEntry, UDSEntry &
entry.append( atom );
}
-void kio_isoProtocol::listDir( const KURL & url )
+void tdeio_isoProtocol::listDir( const KURL & url )
{
- kdDebug() << "kio_isoProtocol::listDir " << url.url() << endl;
+ kdDebug() << "tdeio_isoProtocol::listDir " << url.url() << endl;
TQString path;
if ( !checkNewFile( url.path(), path, url.hasRef() ? url.htmlRef().toInt() : -1 ) )
@@ -263,7 +263,7 @@ void kio_isoProtocol::listDir( const KURL & url )
kdDebug() << "url.path()==" << url.path() << endl;
if (url.hasRef()) redir.setRef(url.htmlRef());
redir.setPath( url.path() + TQString::fromLatin1("/") );
- kdDebug() << "kio_isoProtocol::listDir: redirection " << redir.url() << endl;
+ kdDebug() << "tdeio_isoProtocol::listDir: redirection " << redir.url() << endl;
redirection( redir );
finished();
return;
@@ -310,21 +310,21 @@ void kio_isoProtocol::listDir( const KURL & url )
finished();
- kdDebug() << "kio_isoProtocol::listDir done" << endl;
+ kdDebug() << "tdeio_isoProtocol::listDir done" << endl;
}
-void kio_isoProtocol::stat( const KURL & url )
+void tdeio_isoProtocol::stat( const KURL & url )
{
TQString path;
UDSEntry entry;
- kdDebug() << "kio_isoProtocol::stat " << url.url() << endl;
+ kdDebug() << "tdeio_isoProtocol::stat " << url.url() << endl;
if ( !checkNewFile( url.path(), path, url.hasRef() ? url.htmlRef().toInt() : -1 ) )
{
// We may be looking at a real directory - this happens
// when pressing up after being in the root of an archive
TQCString _path( TQFile::encodeName(url.path()));
- kdDebug() << "kio_isoProtocol::stat (stat) on " << _path << endl;
+ kdDebug() << "tdeio_isoProtocol::stat (stat) on " << _path << endl;
struct stat buff;
if ( ::stat( _path.data(), &buff ) == -1 || !S_ISDIR( buff.st_mode ) ) {
kdDebug() << "isdir=" << S_ISDIR( buff.st_mode ) << " errno=" << strerror(errno) << endl;
@@ -336,7 +336,7 @@ void kio_isoProtocol::stat( const KURL & url )
atom.m_uds = TDEIO::UDS_NAME;
atom.m_str = url.fileName();
entry.append( atom );
- kdDebug() << "kio_isoProtocol::stat returning name=" << url.fileName() << endl;
+ kdDebug() << "tdeio_isoProtocol::stat returning name=" << url.fileName() << endl;
atom.m_uds = TDEIO::UDS_FILE_TYPE;
atom.m_long = buff.st_mode & S_IFMT;
@@ -371,7 +371,7 @@ void kio_isoProtocol::stat( const KURL & url )
finished();
}
-void kio_isoProtocol::getFile( const KIsoFile *isoFileEntry, const TQString &path )
+void tdeio_isoProtocol::getFile( const KIsoFile *isoFileEntry, const TQString &path )
{
unsigned long long size, pos = 0;
bool mime=false,zlib=false;
@@ -485,9 +485,9 @@ void kio_isoProtocol::getFile( const KIsoFile *isoFileEntry, const TQString &pat
}
-void kio_isoProtocol::get( const KURL & url )
+void tdeio_isoProtocol::get( const KURL & url )
{
- kdDebug() << "kio_isoProtocol::get" << url.url() << endl;
+ kdDebug() << "tdeio_isoProtocol::get" << url.url() << endl;
TQString path;
if ( !checkNewFile( url.path(), path, url.hasRef() ? url.htmlRef().toInt() : -1 ) )
diff --git a/tdeioslave/iso/iso.h b/tdeioslave/iso/iso.h
index f0393d7cb..b284e2295 100644
--- a/tdeioslave/iso/iso.h
+++ b/tdeioslave/iso/iso.h
@@ -28,11 +28,11 @@
class KIso;
-class kio_isoProtocol : public TDEIO::SlaveBase
+class tdeio_isoProtocol : public TDEIO::SlaveBase
{
public:
- kio_isoProtocol( const TQCString &pool, const TQCString &app );
- virtual ~kio_isoProtocol();
+ tdeio_isoProtocol( const TQCString &pool, const TQCString &app );
+ virtual ~tdeio_isoProtocol();
virtual void listDir( const KURL & url );
virtual void stat( const KURL & url );
diff --git a/tdeioslave/iso/iso.protocol b/tdeioslave/iso/iso.protocol
index cd2d1d28b..150b03634 100644
--- a/tdeioslave/iso/iso.protocol
+++ b/tdeioslave/iso/iso.protocol
@@ -1,5 +1,5 @@
[Protocol]
-exec=kio_iso
+exec=tdeio_iso
protocol=iso
listing=Name,Type,Size,Date,AccessDate,CreationDate,Access,Owner,Group,Link
input=filesystem
diff --git a/tdeioslave/iso/kiso.cpp b/tdeioslave/iso/kiso.cpp
index 7556a3350..513bd7c04 100644
--- a/tdeioslave/iso/kiso.cpp
+++ b/tdeioslave/iso/kiso.cpp
@@ -326,7 +326,7 @@ void KIso::readParams()
{
TDEConfig *config;
- config = new TDEConfig("kio_isorc");
+ config = new TDEConfig("tdeio_isorc");
showhidden=config->readBoolEntry("showhidden",false);
showrr=config->readBoolEntry("showrr",true);
diff --git a/tdeioslave/iso/kio_iso.desktop b/tdeioslave/iso/tdeio_iso.desktop
index 8578f44b4..8578f44b4 100644
--- a/tdeioslave/iso/kio_iso.desktop
+++ b/tdeioslave/iso/tdeio_iso.desktop
diff --git a/tdeioslave/iso/kio_isorc b/tdeioslave/iso/tdeio_isorc
index 3a874172e..3a874172e 100644
--- a/tdeioslave/iso/kio_isorc
+++ b/tdeioslave/iso/tdeio_isorc
diff --git a/tdeioslave/metainfo/CMakeLists.txt b/tdeioslave/metainfo/CMakeLists.txt
index 9b27a8652..75ed33dff 100644
--- a/tdeioslave/metainfo/CMakeLists.txt
+++ b/tdeioslave/metainfo/CMakeLists.txt
@@ -28,9 +28,9 @@ link_directories(
install( FILES metainfo.protocol DESTINATION ${SERVICES_INSTALL_DIR} )
-##### kio_metainfo ##############################
+##### tdeio_metainfo ##############################
-set( target kio_metainfo )
+set( target tdeio_metainfo )
set( ${target}_SRCS
metainfo.cpp
diff --git a/tdeioslave/metainfo/Makefile.am b/tdeioslave/metainfo/Makefile.am
index a5575d9ff..fd089f7a5 100644
--- a/tdeioslave/metainfo/Makefile.am
+++ b/tdeioslave/metainfo/Makefile.am
@@ -5,11 +5,11 @@ INCLUDES = $(all_includes)
AM_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
METASOURCES = AUTO
-kde_module_LTLIBRARIES = kio_metainfo.la
+kde_module_LTLIBRARIES = tdeio_metainfo.la
-kio_metainfo_la_SOURCES = metainfo.cpp
-kio_metainfo_la_LIBADD = $(LIB_KIO) $(LIB_QT) $(LIB_TDECORE)
-kio_metainfo_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN)
+tdeio_metainfo_la_SOURCES = metainfo.cpp
+tdeio_metainfo_la_LIBADD = $(LIB_KIO) $(LIB_QT) $(LIB_TDECORE)
+tdeio_metainfo_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN)
noinst_HEADERS = metainfo.h
diff --git a/tdeioslave/metainfo/metainfo.cpp b/tdeioslave/metainfo/metainfo.cpp
index abc5cdd96..68f07c800 100644
--- a/tdeioslave/metainfo/metainfo.cpp
+++ b/tdeioslave/metainfo/metainfo.cpp
@@ -42,11 +42,11 @@ extern "C"
int kdemain(int argc, char **argv)
{
- TDEApplication app(argc, argv, "kio_metainfo", false, true);
+ TDEApplication app(argc, argv, "tdeio_metainfo", false, true);
if (argc != 4)
{
- kdError() << "Usage: kio_metainfo protocol domain-socket1 domain-socket2" << endl;
+ kdError() << "Usage: tdeio_metainfo protocol domain-socket1 domain-socket2" << endl;
exit(-1);
}
diff --git a/tdeioslave/metainfo/metainfo.protocol b/tdeioslave/metainfo/metainfo.protocol
index f1fa9adac..8609ad520 100644
--- a/tdeioslave/metainfo/metainfo.protocol
+++ b/tdeioslave/metainfo/metainfo.protocol
@@ -1,5 +1,5 @@
[Protocol]
-exec=kio_metainfo
+exec=tdeio_metainfo
protocol=metainfo
input=stream
output=stream
diff --git a/kdoctools/kio_help.cpp b/kdoctools/tdeio_help.cpp
index 19712f826..d6d5f285a 100644
--- a/kdoctools/kio_help.cpp
+++ b/kdoctools/tdeio_help.cpp
@@ -30,7 +30,7 @@
#include <kstandarddirs.h>
#include <kinstance.h>
-#include "kio_help.h"
+#include "tdeio_help.h"
#include <libxslt/xsltutils.h>
#include <libxslt/transform.h>
#include "xslt.h"
@@ -240,7 +240,7 @@ void HelpProtocol::get( const KURL& url )
infoMessage( i18n( "Saving to cache" ) );
TQString cache = file.left( file.length() - 7 );
saveToCache( mParsed, locateLocal( "cache",
- "kio_help" + cache +
+ "tdeio_help" + cache +
"cache.bz2" ) );
}
} else infoMessage( i18n( "Using cached version" ) );
@@ -333,7 +333,7 @@ void HelpProtocol::mimetype( const KURL &)
finished();
}
// Copied from kio_file to avoid redirects
#define MAX_IPC_SIZE (1024*32)
@@ -333,7 +333,7 @@ void HelpProtocol::mimetype( const KURL &)
finished();
}
-// Copied from kio_file to avoid redirects
+// Copied from tdeio_file to avoid redirects
#define MAX_IPC_SIZE (1024*32)
diff --git a/tdeioslave/file/file.cc b/tdeioslave/file/file.cc
index 499a69330..c8112c3b5 100644
--- a/tdeioslave/file/file.cc
+++ b/tdeioslave/file/file.cc
@@ -113,14 +113,14 @@ extern "C" { KDE_EXPORT int kdemain(int argc, char **argv); }
int kdemain( int argc, char **argv )
{
KLocale::setMainCatalogue("tdelibs");
- TDEInstance instance( "kio_file" );
+ TDEInstance instance( "tdeio_file" );
( void ) TDEGlobal::locale();
kdDebug(7101) << "Starting " << getpid() << endl;
if (argc != 4)
{
- fprintf(stderr, "Usage: kio_file protocol domain-socket1 domain-socket2\n");
+ fprintf(stderr, "Usage: tdeio_file protocol domain-socket1 domain-socket2\n");
exit(-1);
}
@@ -998,7 +998,7 @@ bool FileProtocol::createUDSEntry( const TQString & filename, const TQCString &
{
assert(entry.count() == 0); // by contract :-)
// Note: details = 0 (only "file or directory or symlink or doesn't exist") isn't implemented
// because there's no real performance penalty in kio_file for returning the complete
// details. Please consider doing it in your tdeioslave if you're using this one as a model :)
UDSAtom atom;
atom.m_uds = TDEIO::UDS_NAME;
@@ -998,7 +998,7 @@ bool FileProtocol::createUDSEntry( const TQString & filename, const TQCString &
assert(entry.count() == 0); // by contract :-)
// Note: details = 0 (only "file or directory or symlink or doesn't exist") isn't implemented
- // because there's no real performance penalty in kio_file for returning the complete
+ // because there's no real performance penalty in tdeio_file for returning the complete
// details. Please consider doing it in your tdeioslave if you're using this one as a model :)
UDSAtom atom;
diff --git a/tdeioslave/ftp/ftp.cc b/tdeioslave/ftp/ftp.cc
index 2099457f2..dfe0f338e 100644
--- a/tdeioslave/ftp/ftp.cc
+++ b/tdeioslave/ftp/ftp.cc
@@ -22,7 +22,7 @@
*/
-#define KIO_FTP_PRIVATE_INCLUDE
+#define TDEIO_FTP_PRIVATE_INCLUDE
#include "ftp.h"
#include <sys/stat.h>
@@ -81,17 +81,17 @@
//#undef kdDebug
#define ENABLE_CAN_RESUME
// JPF: somebody should find a better solution for this or move this to KIO
// JPF: anyhow, in KDE 3.2.0 I found diffent MAX_IPC_SIZE definitions!
namespace TDEIO {
enum buffersizes
{ /**
* largest buffer size that should be used to transfer data between
* KIO slaves using the data() function
*/
maximumIpcSize = 32 * 1024,
/**
* this is a reasonable value for an initial read() that a KIO slave
* can do to obtain data via a slow network connection.
*/
initialIpcSize = 2 * 1024,
@@ -140,14 +140,14 @@ extern "C" { KDE_EXPORT int kdemain(int argc, char **argv); }
int kdemain( int argc, char **argv )
{
KLocale::setMainCatalogue("tdelibs");
- TDEInstance instance( "kio_ftp" );
+ TDEInstance instance( "tdeio_ftp" );
( void ) TDEGlobal::locale();
kdDebug(7102) << "Starting " << getpid() << endl;
if (argc != 4)
{
- fprintf(stderr, "Usage: kio_ftp protocol domain-socket1 domain-socket2\n");
+ fprintf(stderr, "Usage: tdeio_ftp protocol domain-socket1 domain-socket2\n");
exit(-1);
}
@@ -2481,7 +2481,7 @@ bool Ftp::ftpFolder(const TQString& path, bool bReportError)
//===============================================================================
// public: copy don't use kio data pump if one side is a local file
// helper: ftpCopyPut called from copy() on upload
// helper: ftpCopyGet called from copy() on download
//===============================================================================
@@ -2590,7 +2590,7 @@ Ftp::StatusCode Ftp::ftpCopyGet(int& iError, int& iCopyFile, const TQString sCop
sPart = TQFile::encodeName(sCopyFile);
}
else if(bPartExists && buff.st_size > 0)
- { // must not be a folder! please fix a similar bug in kio_file!!
+ { // must not be a folder! please fix a similar bug in tdeio_file!!
if(S_ISDIR(buff.st_mode))
{
iError = ERR_DIR_ALREADY_EXIST;
@@ -2607,7 +2607,7 @@ Ftp::StatusCode Ftp::ftpCopyGet(int& iError, int& iCopyFile, const TQString sCop
if(bPartExists && !bResume) // get rid of an unwanted ".part" file
remove(sPart.data());
// JPF: in kio_file overwrite disables ".part" operations. I do not believe
// JPF: that this is a good behaviour!
if(bDestExists) // must delete for overwrite
remove(sDest.data());
@@ -81,17 +81,17 @@
//#undef kdDebug
#define ENABLE_CAN_RESUME
-// JPF: somebody should find a better solution for this or move this to KIO
+// JPF: somebody should find a better solution for this or move this to TDEIO
// JPF: anyhow, in KDE 3.2.0 I found diffent MAX_IPC_SIZE definitions!
namespace TDEIO {
@@ -81,17 +81,17 @@
{ /**
* largest buffer size that should be used to transfer data between
- * KIO slaves using the data() function
+ * TDEIO slaves using the data() function
*/
maximumIpcSize = 32 * 1024,
@@ -81,17 +81,17 @@
maximumIpcSize = 32 * 1024,
/**
- * this is a reasonable value for an initial read() that a KIO slave
+ * this is a reasonable value for an initial read() that a TDEIO slave
* can do to obtain data via a slow network connection.
*/
@@ -2481,7 +2481,7 @@ bool Ftp::ftpFolder(const TQString& path, bool bReportError)
//===============================================================================
-// public: copy don't use kio data pump if one side is a local file
+// public: copy don't use tdeio data pump if one side is a local file
// helper: ftpCopyPut called from copy() on upload
// helper: ftpCopyGet called from copy() on download
@@ -2607,7 +2607,7 @@ Ftp::StatusCode Ftp::ftpCopyGet(int& iError, int& iCopyFile, const TQString sCop
if(bPartExists && !bResume) // get rid of an unwanted ".part" file
remove(sPart.data());
- // JPF: in kio_file overwrite disables ".part" operations. I do not believe
+ // JPF: in tdeio_file overwrite disables ".part" operations. I do not believe
// JPF: that this is a good behaviour!
if(bDestExists) // must delete for overwrite
diff --git a/tdeioslave/http/http.cc b/tdeioslave/http/http.cc
index d944364cc..32ee24ad3 100644
--- a/tdeioslave/http/http.cc
+++ b/tdeioslave/http/http.cc
@@ -99,12 +99,12 @@ extern "C" {
int kdemain( int argc, char **argv )
{
KLocale::setMainCatalogue("tdelibs");
- TDEInstance instance( "kio_http" );
+ TDEInstance instance( "tdeio_http" );
( void ) TDEGlobal::locale();
if (argc != 4)
{
- fprintf(stderr, "Usage: kio_http protocol domain-socket1 domain-socket2\n");
+ fprintf(stderr, "Usage: tdeio_http protocol domain-socket1 domain-socket2\n");
exit(-1);
}
@@ -2056,7 +2056,7 @@ bool HTTPProtocol::httpOpenConnection()
kdDebug(7113) << "(" << m_pid << ") HTTPProtocol::httpOpenConnection" << endl;
setBlockConnection( true );
// kio_http uses its own proxying:
KSocks::self()->disableSocks();
if ( m_state.doProxy )
@@ -2430,7 +2430,7 @@ bool HTTPProtocol::httpOpen()
if ( m_request.offset > 0 )
{
header += TQString("Range: bytes=%1-\r\n").arg(TDEIO::number(m_request.offset));
- kdDebug(7103) << "kio_http : Range = " << TDEIO::number(m_request.offset) << endl;
+ kdDebug(7103) << "tdeio_http : Range = " << TDEIO::number(m_request.offset) << endl;
}
if ( m_request.cache == CC_Reload )
@@ -2842,7 +2842,7 @@ try_again:
{
// We get XML / HTTP without a proper header
// put string back
- kdDebug(7103) << "kio_http: No valid HTTP header found! Document starts with XML/HTML tag" << endl;
+ kdDebug(7103) << "tdeio_http: No valid HTTP header found! Document starts with XML/HTML tag" << endl;
// Document starts with a tag, assume html instead of text/plain
m_strMimeType = "text/html";
@@ -3217,7 +3217,7 @@ try_again:
// content?
else if (strncasecmp(buf, "Content-Encoding:", 17) == 0) {
// This is so wrong !! No wonder kio_http is stripping the
// gzip encoding from downloaded files. This solves multiple
// bug reports and caitoo's problem with downloads when such a
// header is encountered...
@@ -2056,7 +2056,7 @@ bool HTTPProtocol::httpOpenConnection()
kdDebug(7113) << "(" << m_pid << ") HTTPProtocol::httpOpenConnection" << endl;
setBlockConnection( true );
- // kio_http uses its own proxying:
+ // tdeio_http uses its own proxying:
KSocks::self()->disableSocks();
if ( m_state.doProxy )
@@ -3217,7 +3217,7 @@ try_again:
// content?
else if (strncasecmp(buf, "Content-Encoding:", 17) == 0) {
- // This is so wrong !! No wonder kio_http is stripping the
+ // This is so wrong !! No wonder tdeio_http is stripping the
// gzip encoding from downloaded files. This solves multiple
// bug reports and caitoo's problem with downloads when such a